export type U32 = number;
export type Viewtype = ("Unknown" | 
/**
 * Text message.
 */
"Text" | 
/**
 * Image message.
 * If the image is an animated GIF, the type `Viewtype.Gif` should be used.
 */
"Image" | 
/**
 * Animated GIF message.
 */
"Gif" | 
/**
 * Message containing a sticker, similar to image.
 * If possible, the ui should display the image without borders in a transparent way.
 * A click on a sticker will offer to install the sticker set in some future.
 */
"Sticker" | 
/**
 * Message containing an Audio file.
 */
"Audio" | 
/**
 * A voice message that was directly recorded by the user.
 * For all other audio messages, the type `Viewtype.Audio` should be used.
 */
"Voice" | 
/**
 * Video messages.
 */
"Video" | 
/**
 * Message containing any file, eg. a PDF.
 */
"File" | 
/**
 * Message is an invitation to a videochat.
 */
"VideochatInvitation" | 
/**
 * Message is an webxdc instance.
 */
"Webxdc");
export type MessageQuote = (({
    "kind": "JustText";
} & {
    "text": string;
}) | ({
    "kind": "WithMessage";
} & {
    "text": string;
    "messageId": U32;
    "authorDisplayName": string;
    "authorDisplayColor": string;
    "overrideSenderName": (string | null);
    "image": (string | null);
    "isForwarded": boolean;
    "viewType": Viewtype;
}));
export type I64 = number;
export type SystemMessageType = ("Unknown" | "GroupNameChanged" | "GroupImageChanged" | "MemberAddedToGroup" | "MemberRemovedFromGroup" | "AutocryptSetupMessage" | "SecurejoinMessage" | "LocationStreamingEnabled" | "LocationOnly" | 
/**
 * Chat ephemeral message timer is changed.
 */
"EphemeralTimerChanged" | "ChatProtectionEnabled" | "ChatProtectionDisabled" | 
/**
 * Self-sent-message that contains only json used for multi-device-sync;
 * if possible, we attach that to other messages as for locations.
 */
"MultiDeviceSync" | "WebxdcStatusUpdate" | 
/**
 * Webxdc info added with `info` set in `send_webxdc_status_update()`.
 */
"WebxdcInfoMessage");
export type I32 = number;
export type Contact = {
    "address": string;
    "color": string;
    "authName": string;
    "status": string;
    "displayName": string;
    "id": U32;
    "name": string;
    "profileImage": (string | null);
    "nameAndAddr": string;
    "isBlocked": boolean;
    /**
     * True if the contact can be added to verified groups.
     *
     * If this is true
     * UI should display green checkmark after the contact name
     * in contact list items,
     * in chat member list items
     * and in profiles if no chat with the contact exist.
     */
    "isVerified": boolean;
    /**
     * True if the contact profile title should have a green checkmark.
     *
     * This indicates whether 1:1 chat has a green checkmark
     * or will have a green checkmark if created.
     */
    "isProfileVerified": boolean;
    /**
     * The ID of the contact that verified this contact.
     *
     * If this is present,
     * display a green checkmark and "Introduced by ..."
     * string followed by the verifier contact name and address
     * in the contact profile.
     */
    "verifierId": (U32 | null);
    /**
     * the contact's last seen timestamp
     */
    "lastSeen": I64;
    "wasSeenRecently": boolean;
};
export type U64 = number;
export type WebxdcMessageInfo = {
    /**
     * The name of the app.
     *
     * Defaults to the filename if not set in the manifest.
     */
    "name": string;
    /**
     * App icon file name.
     * Defaults to an standard icon if nothing is set in the manifest.
     *
     * To get the file, use dc_msg_get_webxdc_blob(). (not yet in jsonrpc, use rust api or cffi for it)
     *
     * App icons should should be square,
     * the implementations will add round corners etc. as needed.
     */
    "icon": string;
    /**
     * if the Webxdc represents a document, then this is the name of the document
     */
    "document": (string | null);
    /**
     * short string describing the state of the app,
     * sth. as "2 votes", "Highscore: 123",
     * can be changed by the apps
     */
    "summary": (string | null);
    /**
     * URL where the source code of the Webxdc and other information can be found;
     * defaults to an empty string.
     * Implementations may offer an menu or a button to open this URL.
     */
    "sourceCodeUrl": (string | null);
    /**
     * True if full internet access should be granted to the app.
     */
    "internetAccess": boolean;
};
export type DownloadState = ("Done" | "Available" | "Failure" | "Undecipherable" | "InProgress");
export type Usize = number;
/**
 * A single reaction emoji.
 */
export type Reaction = {
    /**
     * Emoji.
     */
    "emoji": string;
    /**
     * Emoji frequency.
     */
    "count": Usize;
    /**
     * True if we reacted with this emoji.
     */
    "isFromSelf": boolean;
};
/**
 * Structure representing all reactions to a particular message.
 */
export type Reactions = {
    /**
     * Map from a contact to it's reaction to message.
     */
    "reactionsByContact": Record<U32, (string)[]>;
    /**
     * Unique reactions and their count, sorted in descending order.
     */
    "reactions": (Reaction)[];
};
export type Message = {
    "id": U32;
    "chatId": U32;
    "fromId": U32;
    "quote": (MessageQuote | null);
    "parentId": (U32 | null);
    "text": string;
    "hasLocation": boolean;
    "hasHtml": boolean;
    "viewType": Viewtype;
    "state": U32;
    /**
     * An error text, if there is one.
     */
    "error": (string | null);
    "timestamp": I64;
    "sortTimestamp": I64;
    "receivedTimestamp": I64;
    "hasDeviatingTimestamp": boolean;
    "subject": string;
    "showPadlock": boolean;
    "isSetupmessage": boolean;
    "isInfo": boolean;
    "isForwarded": boolean;
    /**
     * True if the message was sent by a bot.
     */
    "isBot": boolean;
    /**
     * when is_info is true this describes what type of system message it is
     */
    "systemMessageType": SystemMessageType;
    "duration": I32;
    "dimensionsHeight": I32;
    "dimensionsWidth": I32;
    "videochatType": (U32 | null);
    "videochatUrl": (string | null);
    "overrideSenderName": (string | null);
    "sender": Contact;
    "setupCodeBegin": (string | null);
    "file": (string | null);
    "fileMime": (string | null);
    "fileBytes": U64;
    "fileName": (string | null);
    "webxdcInfo": (WebxdcMessageInfo | null);
    "downloadState": DownloadState;
    "reactions": (Reactions | null);
};
export type Account = (({
    "kind": "Configured";
} & {
    "id": U32;
    "displayName": (string | null);
    "addr": (string | null);
    "profileImage": (string | null);
    "color": string;
}) | ({
    "kind": "Unconfigured";
} & {
    "id": U32;
}));
/**
 * cheaper version of fullchat, omits:
 * - contacts
 * - contact_ids
 * - fresh_message_counter
 * - ephemeral_timer
 * - self_in_group
 * - was_seen_recently
 * - can_send
 *
 * used when you only need the basic metadata of a chat like type, name, profile picture
 */
export type BasicChat = {
    "id": U32;
    "name": string;
    /**
     * True if the chat is protected.
     *
     * UI should display a green checkmark
     * in the chat title,
     * in the chat profile title and
     * in the chatlist item
     * if chat protection is enabled.
     * UI should also display a green checkmark
     * in the contact profile
     * if 1:1 chat with this contact exists and is protected.
     */
    "isProtected": boolean;
    "profileImage": (string | null);
    "archived": boolean;
    "chatType": U32;
    "isUnpromoted": boolean;
    "isSelfTalk": boolean;
    "color": string;
    "isContactRequest": boolean;
    "isProtectionBroken": boolean;
    "isDeviceChat": boolean;
    "isMuted": boolean;
};
export type EventType = (({
    /**
     * The library-user may write an informational string to the log.
     *
     * This event should *not* be reported to the end-user using a popup or something like
     * that.
     */
    "kind": "Info";
} & {
    "msg": string;
}) | ({
    /**
     * Emitted when SMTP connection is established and login was successful.
     */
    "kind": "SmtpConnected";
} & {
    "msg": string;
}) | ({
    /**
     * Emitted when IMAP connection is established and login was successful.
     */
    "kind": "ImapConnected";
} & {
    "msg": string;
}) | ({
    /**
     * Emitted when a message was successfully sent to the SMTP server.
     */
    "kind": "SmtpMessageSent";
} & {
    "msg": string;
}) | ({
    /**
     * Emitted when an IMAP message has been marked as deleted
     */
    "kind": "ImapMessageDeleted";
} & {
    "msg": string;
}) | ({
    /**
     * Emitted when an IMAP message has been moved
     */
    "kind": "ImapMessageMoved";
} & {
    "msg": string;
}) | {
    /**
     * Emitted before going into IDLE on the Inbox folder.
     */
    "kind": "ImapInboxIdle";
} | ({
    /**
     * Emitted when an new file in the $BLOBDIR was created
     */
    "kind": "NewBlobFile";
} & {
    "file": string;
}) | ({
    /**
     * Emitted when an file in the $BLOBDIR was deleted
     */
    "kind": "DeletedBlobFile";
} & {
    "file": string;
}) | ({
    /**
     * The library-user should write a warning string to the log.
     *
     * This event should *not* be reported to the end-user using a popup or something like
     * that.
     */
    "kind": "Warning";
} & {
    "msg": string;
}) | ({
    /**
     * The library-user should report an error to the end-user.
     *
     * As most things are asynchronous, things may go wrong at any time and the user
     * should not be disturbed by a dialog or so.  Instead, use a bubble or so.
     *
     * However, for ongoing processes (eg. configure())
     * or for functions that are expected to fail (eg. autocryptContinueKeyTransfer())
     * it might be better to delay showing these events until the function has really
     * failed (returned false). It should be sufficient to report only the *last* error
     * in a messasge box then.
     */
    "kind": "Error";
} & {
    "msg": string;
}) | ({
    /**
     * An action cannot be performed because the user is not in the group.
     * Reported eg. after a call to
     * setChatName(), setChatProfileImage(),
     * addContactToChat(), removeContactFromChat(),
     * and messages sending functions.
     */
    "kind": "ErrorSelfNotInGroup";
} & {
    "msg": string;
}) | ({
    /**
     * Messages or chats changed.  One or more messages or chats changed for various
     * reasons in the database:
     * - Messages sent, received or removed
     * - Chats created, deleted or archived
     * - A draft has been set
     *
     * `chatId` is set if only a single chat is affected by the changes, otherwise 0.
     * `msgId` is set if only a single message is affected by the changes, otherwise 0.
     */
    "kind": "MsgsChanged";
} & {
    "chatId": U32;
    "msgId": U32;
}) | ({
    /**
     * Reactions for the message changed.
     */
    "kind": "ReactionsChanged";
} & {
    "chatId": U32;
    "msgId": U32;
    "contactId": U32;
}) | ({
    /**
     * There is a fresh message. Typically, the user will show an notification
     * when receiving this message.
     *
     * There is no extra #DC_EVENT_MSGS_CHANGED event send together with this event.
     */
    "kind": "IncomingMsg";
} & {
    "chatId": U32;
    "msgId": U32;
}) | ({
    /**
     * Downloading a bunch of messages just finished. This is an experimental
     * event to allow the UI to only show one notification per message bunch,
     * instead of cluttering the user with many notifications.
     *
     * msg_ids contains the message ids.
     */
    "kind": "IncomingMsgBunch";
} & {
    "msgIds": (U32)[];
}) | ({
    /**
     * Messages were seen or noticed.
     * chat id is always set.
     */
    "kind": "MsgsNoticed";
} & {
    "chatId": U32;
}) | ({
    /**
     * A single message is sent successfully. State changed from  DC_STATE_OUT_PENDING to
     * DC_STATE_OUT_DELIVERED, see `Message.state`.
     */
    "kind": "MsgDelivered";
} & {
    "chatId": U32;
    "msgId": U32;
}) | ({
    /**
     * A single message could not be sent. State changed from DC_STATE_OUT_PENDING or DC_STATE_OUT_DELIVERED to
     * DC_STATE_OUT_FAILED, see `Message.state`.
     */
    "kind": "MsgFailed";
} & {
    "chatId": U32;
    "msgId": U32;
}) | ({
    /**
     * A single message is read by the receiver. State changed from DC_STATE_OUT_DELIVERED to
     * DC_STATE_OUT_MDN_RCVD, see `Message.state`.
     */
    "kind": "MsgRead";
} & {
    "chatId": U32;
    "msgId": U32;
}) | ({
    /**
     * A single message is deleted.
     */
    "kind": "MsgDeleted";
} & {
    "chatId": U32;
    "msgId": U32;
}) | ({
    /**
     * Chat changed.  The name or the image of a chat group was changed or members were added or removed.
     * Or the verify state of a chat has changed.
     * See setChatName(), setChatProfileImage(), addContactToChat()
     * and removeContactFromChat().
     *
     * This event does not include ephemeral timer modification, which
     * is a separate event.
     */
    "kind": "ChatModified";
} & {
    "chatId": U32;
}) | ({
    /**
     * Chat ephemeral timer changed.
     */
    "kind": "ChatEphemeralTimerModified";
} & {
    "chatId": U32;
    "timer": U32;
}) | ({
    /**
     * Contact(s) created, renamed, blocked or deleted.
     *
     * @param data1 (int) If set, this is the contact_id of an added contact that should be selected.
     */
    "kind": "ContactsChanged";
} & {
    "contactId": (U32 | null);
}) | ({
    /**
     * Location of one or more contact has changed.
     *
     * @param data1 (u32) contact_id of the contact for which the location has changed.
     *     If the locations of several contacts have been changed,
     *     this parameter is set to `None`.
     */
    "kind": "LocationChanged";
} & {
    "contactId": (U32 | null);
}) | ({
    /**
     * Inform about the configuration progress started by configure().
     */
    "kind": "ConfigureProgress";
} & {
    /**
     * Progress.
     *
     * 0=error, 1-999=progress in permille, 1000=success and done
     */
    "progress": Usize;
    /**
     * Progress comment or error, something to display to the user.
     */
    "comment": (string | null);
}) | ({
    /**
     * Inform about the import/export progress started by imex().
     *
     * @param data1 (usize) 0=error, 1-999=progress in permille, 1000=success and done
     * @param data2 0
     */
    "kind": "ImexProgress";
} & {
    "progress": Usize;
}) | ({
    /**
     * A file has been exported. A file has been written by imex().
     * This event may be sent multiple times by a single call to imex().
     *
     * A typical purpose for a handler of this event may be to make the file public to some system
     * services.
     *
     * @param data2 0
     */
    "kind": "ImexFileWritten";
} & {
    "path": string;
}) | ({
    /**
     * Progress information of a secure-join handshake from the view of the inviter
     * (Alice, the person who shows the QR code).
     *
     * These events are typically sent after a joiner has scanned the QR code
     * generated by getChatSecurejoinQrCodeSvg().
     *
     * @param data1 (int) ID of the contact that wants to join.
     * @param data2 (int) Progress as:
     *     300=vg-/vc-request received, typically shown as "bob@addr joins".
     *     600=vg-/vc-request-with-auth received, vg-member-added/vc-contact-confirm sent, typically shown as "bob@addr verified".
     *     800=vg-member-added-received received, shown as "bob@addr securely joined GROUP", only sent for the verified-group-protocol.
     *     1000=Protocol finished for this contact.
     */
    "kind": "SecurejoinInviterProgress";
} & {
    "contactId": U32;
    "progress": Usize;
}) | ({
    /**
     * Progress information of a secure-join handshake from the view of the joiner
     * (Bob, the person who scans the QR code).
     * The events are typically sent while secureJoin(), which
     * may take some time, is executed.
     * @param data1 (int) ID of the inviting contact.
     * @param data2 (int) Progress as:
     *     400=vg-/vc-request-with-auth sent, typically shown as "alice@addr verified, introducing myself."
     *     (Bob has verified alice and waits until Alice does the same for him)
     */
    "kind": "SecurejoinJoinerProgress";
} & {
    "contactId": U32;
    "progress": Usize;
}) | {
    /**
     * The connectivity to the server changed.
     * This means that you should refresh the connectivity view
     * and possibly the connectivtiy HTML; see getConnectivity() and
     * getConnectivityHtml() for details.
     */
    "kind": "ConnectivityChanged";
} | {
    "kind": "SelfavatarChanged";
} | ({
    "kind": "WebxdcStatusUpdate";
} & {
    "msgId": U32;
    "statusUpdateSerial": U32;
}) | ({
    /**
     * Inform that a message containing a webxdc instance has been deleted
     */
    "kind": "WebxdcInstanceDeleted";
} & {
    "msgId": U32;
}));
export type Event = {
    /**
     * Event payload.
     */
    "event": EventType;
    /**
     * Account ID.
     */
    "contextId": U32;
};
export type FullChat = {
    "id": U32;
    "name": string;
    /**
     * True if the chat is protected.
     *
     * UI should display a green checkmark
     * in the chat title,
     * in the chat profile title and
     * in the chatlist item
     * if chat protection is enabled.
     * UI should also display a green checkmark
     * in the contact profile
     * if 1:1 chat with this contact exists and is protected.
     */
    "isProtected": boolean;
    "profileImage": (string | null);
    "archived": boolean;
    "chatType": U32;
    "isUnpromoted": boolean;
    "isSelfTalk": boolean;
    "contacts": (Contact)[];
    "contactIds": (U32)[];
    "color": string;
    "freshMessageCounter": Usize;
    "isContactRequest": boolean;
    "isProtectionBroken": boolean;
    "isDeviceChat": boolean;
    "selfInGroup": boolean;
    "isMuted": boolean;
    "ephemeralTimer": U32;
    "canSend": boolean;
    "wasSeenRecently": boolean;
    "mailingListAddress": (string | null);
};
export type ChatListItemFetchResult = (({
    "kind": "ChatListItem";
} & {
    "id": U32;
    "name": string;
    "avatarPath": (string | null);
    "color": string;
    "lastUpdated": (I64 | null);
    "summaryText1": string;
    "summaryText2": string;
    "summaryStatus": U32;
    /**
     * showing preview if last chat message is image
     */
    "summaryPreviewImage": (string | null);
    "isProtected": boolean;
    "isGroup": boolean;
    "freshMessageCounter": Usize;
    "isSelfTalk": boolean;
    "isDeviceTalk": boolean;
    "isSendingLocation": boolean;
    "isSelfInGroup": boolean;
    "isArchived": boolean;
    "isPinned": boolean;
    "isMuted": boolean;
    "isContactRequest": boolean;
    /**
     * true when chat is a broadcastlist
     */
    "isBroadcast": boolean;
    /**
     * contact id if this is a dm chat (for view profile entry in context menu)
     */
    "dmChatContact": (U32 | null);
    "wasSeenRecently": boolean;
    "lastMessageType": (Viewtype | null);
    "lastMessageId": (U32 | null);
}) | ({
    "kind": "ArchiveLink";
} & {
    "freshMessageCounter": Usize;
}) | ({
    "kind": "Error";
} & {
    "id": U32;
    "error": string;
}));
export type MessageLoadResult = (({
    "kind": "message";
} & Message) | ({
    "kind": "loadingError";
} & {
    "error": string;
}));
export type MessageSearchResult = {
    "id": U32;
    "authorProfileImage": (string | null);
    /**
     * if sender name if overridden it will show it as ~alias
     */
    "authorName": string;
    "authorColor": string;
    "authorId": U32;
    "chatProfileImage": (string | null);
    "chatColor": string;
    "chatName": string;
    "chatType": U32;
    "isChatProtected": boolean;
    "isChatContactRequest": boolean;
    "isChatArchived": boolean;
    "message": string;
    "timestamp": I64;
};
export type HttpResponse = {
    /**
     * base64-encoded response body.
     */
    "blob": string;
    /**
     * MIME type, e.g. "text/plain" or "text/html".
     */
    "mimetype": (string | null);
    /**
     * Encoding, e.g. "utf-8".
     */
    "encoding": (string | null);
};
export type ChatVisibility = ("Normal" | "Archived" | "Pinned");
export type F64 = number;
export type MessageData = {
    "text": (string | null);
    "html": (string | null);
    "viewtype": (Viewtype | null);
    "file": (string | null);
    "location": ([F64, F64] | null);
    "overrideSenderName": (string | null);
    "quotedMessageId": (U32 | null);
};
export type EphemeralTimer = ({
    /**
     * Timer is disabled.
     */
    "variant": "disabled";
} | ({
    /**
     * Timer is enabled.
     */
    "variant": "enabled";
} & {
    /**
     * Timer duration in seconds.
     *
     * The value cannot be 0.
     */
    "duration": U32;
}));
export type MessageInfo = {
    "rawtext": string;
    "ephemeralTimer": EphemeralTimer;
    /**
     * When message is ephemeral this contains the timestamp of the message expiry
     */
    "ephemeralTimestamp": (I64 | null);
    "error": (string | null);
    "rfc724Mid": string;
    "serverUrls": (string)[];
    "hopInfo": (string | null);
};
export type MessageNotificationInfo = {
    "id": U32;
    "chatId": U32;
    "accountId": U32;
    "image": (string | null);
    "imageMimeType": (string | null);
    "chatName": string;
    "chatProfileImage": (string | null);
    /**
     * also known as summary_text1
     */
    "summaryPrefix": (string | null);
    /**
     * also known as summary_text2
     */
    "summaryText": string;
};
export type MuteDuration = ({
    "kind": "NotMuted";
} | {
    "kind": "Forever";
} | ({
    "kind": "Until";
} & {
    "duration": I64;
}));
export type ProviderInfo = {
    /**
     * Unique ID, corresponding to provider database filename.
     */
    "id": string;
    "beforeLoginHint": string;
    "overviewPage": string;
    "status": U32;
};
export type Qr = (({
    "kind": "askVerifyContact";
} & {
    "contact_id": U32;
    "fingerprint": string;
    "invitenumber": string;
    "authcode": string;
}) | ({
    "kind": "askVerifyGroup";
} & {
    "grpname": string;
    "grpid": string;
    "contact_id": U32;
    "fingerprint": string;
    "invitenumber": string;
    "authcode": string;
}) | ({
    "kind": "fprOk";
} & {
    "contact_id": U32;
}) | ({
    "kind": "fprMismatch";
} & {
    "contact_id": (U32 | null);
}) | ({
    "kind": "fprWithoutAddr";
} & {
    "fingerprint": string;
}) | ({
    "kind": "account";
} & {
    "domain": string;
}) | ({
    "kind": "backup";
} & {
    "ticket": string;
}) | ({
    "kind": "webrtcInstance";
} & {
    "domain": string;
    "instance_pattern": string;
}) | ({
    "kind": "addr";
} & {
    "contact_id": U32;
    "draft": (string | null);
}) | ({
    "kind": "url";
} & {
    "url": string;
}) | ({
    "kind": "text";
} & {
    "text": string;
}) | ({
    "kind": "withdrawVerifyContact";
} & {
    "contact_id": U32;
    "fingerprint": string;
    "invitenumber": string;
    "authcode": string;
}) | ({
    "kind": "withdrawVerifyGroup";
} & {
    "grpname": string;
    "grpid": string;
    "contact_id": U32;
    "fingerprint": string;
    "invitenumber": string;
    "authcode": string;
}) | ({
    "kind": "reviveVerifyContact";
} & {
    "contact_id": U32;
    "fingerprint": string;
    "invitenumber": string;
    "authcode": string;
}) | ({
    "kind": "reviveVerifyGroup";
} & {
    "grpname": string;
    "grpid": string;
    "contact_id": U32;
    "fingerprint": string;
    "invitenumber": string;
    "authcode": string;
}) | ({
    "kind": "login";
} & {
    "address": string;
}));
export type MessageListItem = (({
    "kind": "message";
} & {
    "msg_id": U32;
}) | ({
    /**
     * Day marker, separating messages that correspond to different
     * days according to local time.
     */
    "kind": "dayMarker";
} & {
    /**
     * Marker timestamp, for day markers, in unix milliseconds
     */
    "timestamp": I64;
}));
export type Location = {
    "locationId": U32;
    "isIndependent": boolean;
    "latitude": F64;
    "longitude": F64;
    "accuracy": F64;
    "timestamp": I64;
    "contactId": U32;
    "msgId": U32;
    "chatId": U32;
    "marker": (string | null);
};
export type MessageReadReceipt = {
    "contactId": U32;
    "timestamp": I64;
};
